@@ -7,7 +7,7 @@ use warnings;
 use Readonly;
 use Geoffrey::Action::Table;
 
-$Geoffrey::VERSION = '0.000202';
+$Geoffrey::VERSION = '0.000203';
 
 use parent 'Geoffrey::Role::Core';
 
@@ -17,7 +17,7 @@ sub new {
     my $class = shift;
     my $self  = $class->SUPER::new(@_);
     bless $self, $class;
-    $self->converter->check_version( $self->dbh->get_info($IDX_DATABASE_DRIVER) );
+    $self->converter->check_version($self->dbh->get_info($IDX_DATABASE_DRIVER));
     $self->_prepare_tables;
     return $self;
 }
@@ -25,9 +25,9 @@ sub new {
 sub _prepare_tables {
     my ($self) = @_;
 
-    my $o_action_table = Geoffrey::Action::Table->new( dbh => $self->dbh, converter => $self->converter );
+    my $o_action_table = Geoffrey::Action::Table->new(dbh => $self->dbh, converter => $self->converter);
 
-    my $hr_changelog_table = $self->converter->get_changelog_table_hashref( $self->dbh, $self->schema );
+    my $hr_changelog_table = $self->converter->get_changelog_table_hashref($self->dbh, $self->schema);
     $o_action_table->add($hr_changelog_table) if $hr_changelog_table;
     return $hr_changelog_table;
 }
@@ -57,28 +57,39 @@ sub writer {
 }
 
 sub read {
-    my ( $self, $s_changelog_root ) = @_;
+    my ($self, $s_changelog_root) = @_;
     return $self->reader->run($s_changelog_root);
 }
 
 sub write {
-    my ( $self, $s_changelog_root, $s_schema, $dump ) = @_;
-    return $self->writer->run( $s_changelog_root, $s_schema, $dump );
+    my ($self, $s_changelog_root, $s_schema, $dump) = @_;
+    return $self->writer->run($s_changelog_root, $s_schema, $dump);
 }
 
 sub delete {
-    my ( $self, $s_changeset_id ) = @_;
+    my ($self, $s_changeset_id) = @_;
     return $self->changelog_io->delete($s_changeset_id);
 }
 
 sub insert {
-    my ( $self, $s_file, $hr_changeset ) = @_;
-    return $self->changelog_io->insert( $s_file, $hr_changeset );
+    my ($self, $s_file, $hr_changeset) = @_;
+    return $self->changelog_io->insert($s_file, $hr_changeset);
 }
 
 sub rewrite {
-    my ( $self, $s_changeset_id, $hr_changeset ) = @_;
-    return $self->delete($s_changeset_id) ? $self->insert($hr_changeset) : 0;
+    my ($self, $hr_changeset) = @_;
+    return unless $hr_changeset->{id};
+    return $self->delete($hr_changeset->{id}) ? $self->insert(q//, $hr_changeset) : 0;
+}
+
+sub load_changeset {
+    my ($self, $s_changeset_id, $s_file) = @_;
+    if (!$s_changeset_id) {
+        require Geoffrey::Exception::RequiredValue;
+        Geoffrey::Exception::RequiredValue::throw_id();
+    }
+
+    return $self->changelog_io->load_changeset($s_changeset_id, $s_file);
 }
 
 1;
@@ -95,7 +106,7 @@ Geoffrey - Continuous Database Migration
 
 =head1 VERSION
 
-Version 0.000202
+Version 0.000203
 
 =head1 DESCRIPTION
 
@@ -159,6 +170,9 @@ Insert a new changeset
 
 The sub delete and insert combined
 
+=head2 load_changeset
+
+Get the value of a changeset by given changeset id.
 
 =head1 MOTIVATION
 
